#line 2 "PRISM.yy.cpp"

#line 4 "PRISM.yy.cpp"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer PRISM_create_buffer
#define yy_delete_buffer PRISM_delete_buffer
#define yy_flex_debug PRISM_flex_debug
#define yy_init_buffer PRISM_init_buffer
#define yy_flush_buffer PRISM_flush_buffer
#define yy_load_buffer_state PRISM_load_buffer_state
#define yy_switch_to_buffer PRISM_switch_to_buffer
#define yyin PRISMin
#define yyleng PRISMleng
#define yylex PRISMlex
#define yylineno PRISMlineno
#define yyout PRISMout
#define yyrestart PRISMrestart
#define yytext PRISMtext
#define yywrap PRISMwrap
#define yyalloc PRISMalloc
#define yyrealloc PRISMrealloc
#define yyfree PRISMfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE PRISMrestart(PRISMin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int PRISMleng;

extern FILE *PRISMin, *PRISMout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up PRISMtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up PRISMtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via PRISMrestart()), so that the user can continue scanning by
	 * just pointing PRISMin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when PRISMtext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int PRISMleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow PRISMwrap()'s to do buffer switches
 * instead of setting up a fresh PRISMin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void PRISMrestart (FILE *input_file  );
void PRISM_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE PRISM_create_buffer (FILE *file,int size  );
void PRISM_delete_buffer (YY_BUFFER_STATE b  );
void PRISM_flush_buffer (YY_BUFFER_STATE b  );
void PRISMpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void PRISMpop_buffer_state (void );

static void PRISMensure_buffer_stack (void );
static void PRISM_load_buffer_state (void );
static void PRISM_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER PRISM_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE PRISM_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE PRISM_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE PRISM_scan_bytes (yyconst char *bytes,int len  );

void *PRISMalloc (yy_size_t  );
void *PRISMrealloc (void *,yy_size_t  );
void PRISMfree (void *  );

#define yy_new_buffer PRISM_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        PRISMensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            PRISM_create_buffer(PRISMin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        PRISMensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            PRISM_create_buffer(PRISMin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *PRISMin = (FILE *) 0, *PRISMout = (FILE *) 0;

typedef int yy_state_type;

extern int PRISMlineno;

int PRISMlineno = 1;

extern char *PRISMtext;
#define yytext_ptr PRISMtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up PRISMtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	PRISMleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 88
#define YY_END_OF_BUFFER 89
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[253] =
    {   0,
        0,    0,    0,    0,   89,   88,    2,   87,   74,   85,
       80,   57,   86,   69,   70,   78,   77,   66,   76,   73,
       79,   50,   67,   63,   81,   68,   82,   84,   49,   36,
       35,   45,   40,   46,   37,   33,   34,   71,   72,   83,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   64,   58,   65,   75,    2,
       62,    0,   65,   56,    0,   51,    1,    3,    0,   50,
        0,   72,   64,   71,   59,   61,   60,   49,   49,   49,
       49,   49,   22,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   49,

       49,   49,   49,   49,   49,   55,   53,    3,   54,    0,
       52,   49,   49,   49,   49,   49,   49,   49,   49,   49,
       49,   49,   49,   49,   49,   49,   49,   49,   49,   19,
       49,   49,   32,   26,   31,   49,   49,   49,   49,   49,
       49,   49,   49,   12,    0,   53,   53,    0,   54,   52,
       41,   42,   47,   48,   38,   39,   20,   49,   29,   49,
       28,   49,   49,   49,   49,   49,   49,   49,   13,   49,
       49,   49,   49,   49,   49,   17,   49,   49,   49,   23,
        0,   53,    0,   53,    0,   54,    7,   49,   49,   49,
       49,   24,   18,   49,   49,    6,   15,   11,   49,   49,

        9,   49,   49,   49,    0,   53,   21,   49,   49,   49,
       49,   49,    8,    4,   49,   49,   49,   49,   14,   49,
       49,   49,   10,   49,   49,   43,   49,   16,   49,   49,
       49,   49,   49,    5,   49,   49,   49,   49,   44,   49,
       49,   27,   49,   49,   49,   49,   49,   30,   49,   49,
       25,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    5,    6,    1,    1,    7,    8,    9,   10,
       11,   12,   13,   14,   15,   16,   17,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   19,   20,   21,
       22,   23,   24,    1,   25,   25,   26,   25,   27,   28,
       25,   25,   29,   25,   25,   30,   25,   25,   25,   31,
       25,   32,   33,   25,   34,   25,   25,   35,   25,   25,
       36,    1,   37,   38,   25,    1,   39,   40,   41,   42,

       43,   44,   45,   46,   47,   25,   25,   48,   49,   50,
       51,   52,   25,   53,   54,   55,   56,   57,   58,   59,
       25,   25,   60,   61,   62,   63,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[64] =
    {   0,
        1,    1,    2,    3,    1,    3,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    4,    1,    5,    1,    1,
        1,    1,    1,    1,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    1,    1,    1,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    1,
        1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[257] =
    {   0,
        0,    0,    0,    0,  314,  315,   62,  315,  291,  294,
      288,  315,  315,  315,  315,  315,  315,  315,  287,  293,
       53,   51,  285,  315,   61,  285,  284,  315,    0,    0,
        0,    0,  256,  255,  254,    0,    0,  315,  315,  315,
       20,   21,   24,  252,   34,  253,  250,  260,   42,  247,
       35,  254,  241,  242,  255,  315,  315,  315,  315,   88,
      315,   80,  315,  315,  275,  315,  315,    0,    0,   79,
       86,  315,  315,  315,  315,  315,  315,    0,   61,   63,
       64,  241,    0,  241,  241,  233,  239,  245,  238,  234,
      231,  232,   60,  242,  222,  228,  229,  236,  227,  223,

       62,  217,  223,  217,  219,  315,   91,    0,   98,  253,
      115,  211,  219,  209,  217,  207,  215,  216,  209,  221,
      221,  219,   83,  205,  219,  208,  216,  200,  198,    0,
      214,  209,    0,    0,    0,  195,  208,  210,  206,  207,
      207,  204,  201,    0,  134,  315,  126,  142,  315,  315,
        0,    0,    0,    0,    0,    0,    0,  188,    0,  194,
        0,  191,  189,  196,  195,  182,  180,  196,    0,  179,
      180,  184,  183,  187,  180,    0,  189,  174,  180,    0,
      207,  120,  158,  315,  206,  147,    0,  180,   67,  180,
      163,    0,    0,  172,  171,    0,    0,    0,  175,  161,

        0,  175,  167,  166,  183,  154,    0,  145,  160,  141,
      157,  155,    0,    0,  150,  145,  136,  135,    0,  135,
      139,  133,    0,  132,  135,    0,  126,    0,  137,  137,
      129,  120,  119,    0,  108,  114,  104,  110,    0,   90,
       82,    0,   84,   82,   73,   82,   65,    0,   49,   50,
        0,  315,  202,   82,  207,  212
    } ;

static yyconst flex_int16_t yy_def[257] =
    {   0,
      252,    1,    1,    1,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252,  252,  253,
      252,  252,  252,  252,  252,  252,  252,  252,  254,  254,
      254,  254,  254,  254,  254,  254,  254,  252,  252,  252,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      254,  254,  254,  254,  254,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  255,  256,  252,
      252,  252,  252,  252,  252,  252,  252,  254,  254,  254,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,

      254,  254,  254,  254,  254,  252,  252,  255,  252,  252,
      252,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      254,  254,  254,  254,  252,  252,  252,  252,  252,  252,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      252,  252,  252,  252,  252,  252,  254,  254,  254,  254,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,

      254,  254,  254,  254,  252,  252,  254,  254,  254,  254,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      254,  254,  254,  254,  254,  254,  254,  254,  254,  254,
      254,    0,  252,  252,  252,  252
    } ;

static yyconst flex_int16_t yy_nxt[379] =
    {   0,
        6,    7,    8,    7,    9,   10,   11,   12,   13,   14,
       15,   16,   17,   18,   19,   20,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   29,   31,   32,   29,
       33,   34,   35,   36,   37,   38,   39,   40,   29,   41,
       42,   43,   44,   45,   46,   29,   47,   48,   49,   50,
       29,   51,   52,   53,   54,   29,   55,   29,   29,   56,
       57,   58,   59,   60,   67,   60,   69,   73,   70,   68,
       82,   84,   89,  100,   86,   85,   83,   71,   87,   74,
       95,   90,   75,   96,   91,  106,   78,  101,   97,   60,
      251,   60,   98,   71,   69,  250,   70,   62,  110,  112,

      110,  114,  116,  111,  139,   71,  128,  113,  107,  115,
      117,  129,  140,  208,  130,  147,  131,  145,  146,  249,
      146,   71,  248,  209,  148,  149,  247,  149,  246,  162,
      245,  163,  111,  145,  146,  164,  244,  182,  146,  243,
      148,  149,  150,  147,  150,  149,  181,  146,  181,  146,
      242,  182,  183,  184,  185,  184,  185,  241,  150,  186,
      240,  239,  150,  146,  186,  238,  237,  146,  183,  184,
      205,  206,  205,  184,  149,  206,  149,  236,  235,  234,
      233,  184,  232,  184,  231,  230,  229,  228,  227,  226,
      149,  225,  224,  223,  149,  222,  221,  184,  220,  219,

      206,  184,   65,   65,  218,   65,   65,  108,  217,  108,
      108,  108,  109,  109,  216,  215,  109,  214,  213,  212,
      211,  210,  207,  186,  182,  204,  203,  202,  201,  200,
      199,  198,  197,  196,  195,  194,  193,  192,  191,  190,
      189,  188,  187,  180,  179,  178,  177,  176,  175,  174,
      173,  172,  171,  170,  169,  168,  167,  166,  165,  161,
      160,  159,  158,  157,  156,  155,  154,  153,  152,  151,
      111,  144,  143,  142,  141,  138,  137,  136,  135,  134,
      133,  132,  127,  126,  125,  124,  123,  122,  121,  120,
      119,  118,  107,  105,  104,  103,  102,   99,   94,   93,

       92,   88,   81,   80,   79,   77,   76,   72,   66,   64,
       63,   62,   61,  252,    5,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252
    } ;

static yyconst flex_int16_t yy_chk[379] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    7,   21,    7,   22,   25,   22,   21,
       41,   42,   45,   51,   43,   42,   41,   22,   43,   25,
       49,   45,   25,   49,   45,   62,  254,   51,   49,   60,
      250,   60,   49,   22,   70,  249,   70,   62,   71,   79,

       71,   80,   81,   71,  101,   70,   93,   79,  107,   80,
       81,   93,  101,  189,   93,  109,   93,  107,  107,  247,
      107,   70,  246,  189,  109,  109,  245,  109,  244,  123,
      243,  123,  111,  107,  107,  123,  241,  182,  107,  240,
      109,  109,  111,  147,  111,  109,  145,  182,  145,  182,
      238,  145,  147,  147,  148,  147,  148,  237,  111,  148,
      236,  235,  111,  182,  186,  233,  232,  182,  147,  147,
      183,  206,  183,  147,  186,  183,  186,  231,  230,  229,
      227,  206,  225,  206,  224,  222,  221,  220,  218,  217,
      186,  216,  215,  212,  186,  211,  210,  206,  209,  208,

      205,  206,  253,  253,  204,  253,  253,  255,  203,  255,
      255,  255,  256,  256,  202,  200,  256,  199,  195,  194,
      191,  190,  188,  185,  181,  179,  178,  177,  175,  174,
      173,  172,  171,  170,  168,  167,  166,  165,  164,  163,
      162,  160,  158,  143,  142,  141,  140,  139,  138,  137,
      136,  132,  131,  129,  128,  127,  126,  125,  124,  122,
      121,  120,  119,  118,  117,  116,  115,  114,  113,  112,
      110,  105,  104,  103,  102,  100,   99,   98,   97,   96,
       95,   94,   92,   91,   90,   89,   88,   87,   86,   85,
       84,   82,   65,   55,   54,   53,   52,   50,   48,   47,

       46,   44,   35,   34,   33,   27,   26,   23,   20,   19,
       11,   10,    9,    5,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  252,  252,  252,  252
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int PRISM_flex_debug;
int PRISM_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *PRISMtext;
#line 1 "PRISM.l"
#line 9 "PRISM.l"
#include "AST.h"
using namespace prismparser_ast;
using namespace prismparser;

#include "PRISM.tab.hpp"
#include "PRISMParser.h"

extern Substitution formulas;

extern void PRISMerror(char *s);
extern void PRISMerror(const std::string&);

namespace prismparser {
  extern int line_number;
}

namespace prismparser {
  void emit(int current_token = BOGY);
  void comment();
  int token;
  int check_type();

  extern Substitution formulas;
}
using namespace prismparser;


#line 673 "PRISM.yy.cpp"

#define INITIAL 0
#define line_directive 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int PRISMlex_destroy (void );

int PRISMget_debug (void );

void PRISMset_debug (int debug_flag  );

YY_EXTRA_TYPE PRISMget_extra (void );

void PRISMset_extra (YY_EXTRA_TYPE user_defined  );

FILE *PRISMget_in (void );

void PRISMset_in  (FILE * in_str  );

FILE *PRISMget_out (void );

void PRISMset_out  (FILE * out_str  );

int PRISMget_leng (void );

char *PRISMget_text (void );

int PRISMget_lineno (void );

void PRISMset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int PRISMwrap (void );
#else
extern int PRISMwrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( PRISMtext, PRISMleng, 1, PRISMout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( PRISMin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( PRISMin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, PRISMin))==0 && ferror(PRISMin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(PRISMin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int PRISMlex (void);

#define YY_DECL int PRISMlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after PRISMtext and PRISMleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 38 "PRISM.l"


#line 864 "PRISM.yy.cpp"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! PRISMin )
			PRISMin = stdin;

		if ( ! PRISMout )
			PRISMout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			PRISMensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				PRISM_create_buffer(PRISMin,YY_BUF_SIZE );
		}

		PRISM_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of PRISMtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 253 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 315 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 40 "PRISM.l"
{ emit(); comment();         }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 41 "PRISM.l"
{ emit();                    }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 42 "PRISM.l"
{ emit();                    }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 43 "PRISM.l"
{ emit(MODULE);    return token; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 44 "PRISM.l"
{ emit(ENDMODULE); return token; }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 45 "PRISM.l"
{ emit(INPUT);     return token; }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 46 "PRISM.l"
{ emit(CONSTANT);  return token; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 47 "PRISM.l"
{ emit(GLOBAL);    return token; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 48 "PRISM.l"
{ emit(PARAM);     return token; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 49 "PRISM.l"
{ emit(FORMULA);   return token; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 50 "PRISM.l"
{ emit(LABEL);   return token; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 51 "PRISM.l"
{ emit(VAR);       return token; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 52 "PRISM.l"
{ emit(INIT);      return token; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 53 "PRISM.l"
{ emit(ENDINIT);   return token; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 54 "PRISM.l"
{ emit(INVAR);     return token; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 55 "PRISM.l"
{ emit(ENDINVAR);  return token; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 56 "PRISM.l"
{ emit(PRED);      return token; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 57 "PRISM.l"
{ emit(FLOAT);     return token; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 58 "PRISM.l"
{ emit(INTEGER);   return token; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 59 "PRISM.l"
{ emit(BOOL);      return token; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 60 "PRISM.l"
{ emit(DOUBLE);    return token; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 61 "PRISM.l"
{ emit(BV);        return token; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 62 "PRISM.l"
{ emit(TRUE);      return token; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 63 "PRISM.l"
{ emit(FALSE);     return token; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 64 "PRISM.l"
{ emit(NONDET);    return token; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 65 "PRISM.l"
{ emit(NONDET);    return token; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 66 "PRISM.l"
{ emit(STOCH);     return token; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 67 "PRISM.l"
{ emit(PROBAB);    return token; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 68 "PRISM.l"
{ emit(STOCH);     return token; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 69 "PRISM.l"
{ emit(PROBAB);    return token; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 70 "PRISM.l"
{ emit(MIN_OP);    return token; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 71 "PRISM.l"
{ emit(MAX_OP);    return token; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 72 "PRISM.l"
{ emit(UNTIL);     return token; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 73 "PRISM.l"
{ emit(NEXT);      return token; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 74 "PRISM.l"
{ emit(FINALLY);   return token; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 75 "PRISM.l"
{ emit(CUMULATIVE);return token; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 76 "PRISM.l"
{ emit(STEADY);    return token; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 77 "PRISM.l"
{ emit(STEADYMAX); return token; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 78 "PRISM.l"
{ emit(STEADYMIN); return token; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 79 "PRISM.l"
{ emit(PROB);      return token; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 80 "PRISM.l"
{ emit(PROBMAX);   return token; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 81 "PRISM.l"
{ emit(PROBMIN);   return token; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 83 "PRISM.l"
{ emit(REWARDS);   return token; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 84 "PRISM.l"
{ emit(ENDREWARDS);return token; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 85 "PRISM.l"
{ emit(I_REW);     return token; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 86 "PRISM.l"
{ emit(REW);       return token; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 87 "PRISM.l"
{ emit(REWMAX);    return token; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 88 "PRISM.l"
{ emit(REWMIN);    return token; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 90 "PRISM.l"
{ 
	emit(IDENTIFIER);  
	PRISMlval.string_const = strdup(PRISMtext) ;
	return token; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 95 "PRISM.l"
{ emit(INT_CONSTANT); 
			  PRISMlval.int_const = atoi(PRISMtext);
                          return token; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 98 "PRISM.l"
{ emit(DOTS);      return token; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 99 "PRISM.l"
{ emit(FLOAT_CONSTANT); 
			  PRISMlval.float_const = atof(PRISMtext);
                          return token; }
	YY_BREAK
case 53:
/* rule 53 can match eol */
YY_RULE_SETUP
#line 102 "PRISM.l"
{ emit(FLOAT_CONSTANT); 
			   PRISMlval.float_const = atof(PRISMtext);
                           return token; }
	YY_BREAK
case 54:
/* rule 54 can match eol */
YY_RULE_SETUP
#line 105 "PRISM.l"
{ emit(FLOAT_CONSTANT); 
			  PRISMlval.float_const = atof(PRISMtext);
                          return token; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 109 "PRISM.l"
{ emit(BV_CONSTANT); 
			  char *buf;
			  std::string str = buf = strdup( PRISMtext );
			  PRISMlval.bv_const.size = str.size()-2;
			  long long value = 0;
			  for(std::string::iterator i = str.begin(); i!=str.end(); ++i)
				switch(*i) {
					case '0': value *= 2; break;
					case '1': value = value * 2 + 1; break;
					break;
			        }
			  PRISMlval.bv_const.value = value;
			  delete buf;
                          return token; 
			}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 125 "PRISM.l"
{ emit(DISTR);     return token; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 126 "PRISM.l"
{ emit('&');       return token; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 127 "PRISM.l"
{ emit('|');       return token; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 128 "PRISM.l"
{ emit(LE_OP);     return token; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 129 "PRISM.l"
{ emit(GE_OP);     return token; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 130 "PRISM.l"
{ emit(EQ_OP);     return token; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 131 "PRISM.l"
{ emit(NE_OP);     return token; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 132 "PRISM.l"
{ emit(';');       return token; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 133 "PRISM.l"
{ emit('{');       return token; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 134 "PRISM.l"
{ emit('}');       return token; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 135 "PRISM.l"
{ emit(',');       return token; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 136 "PRISM.l"
{ emit(':');       return token; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 137 "PRISM.l"
{ emit('=');       return token; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 138 "PRISM.l"
{ emit('(');       return token; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 139 "PRISM.l"
{ emit(')');       return token; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 140 "PRISM.l"
{ emit('[');       return token; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 141 "PRISM.l"
{ emit(']');       return token; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 142 "PRISM.l"
{ emit('.');       return token; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 143 "PRISM.l"
{ emit('!');       return token; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 144 "PRISM.l"
{ emit('~');       return token; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 145 "PRISM.l"
{ emit('-');       return token; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 146 "PRISM.l"
{ emit('+');       return token; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 147 "PRISM.l"
{ emit('*');       return token; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 148 "PRISM.l"
{ emit('/');       return token; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 149 "PRISM.l"
{ emit('%');       return token; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 150 "PRISM.l"
{ emit('<');       return token; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 151 "PRISM.l"
{ emit('>');       return token; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 152 "PRISM.l"
{ emit('^');       return token; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 153 "PRISM.l"
{ emit('?');       return token; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 154 "PRISM.l"
{ emit(QUOTE);     return token; }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 155 "PRISM.l"
{ emit(PRIMED);    return token; }
	YY_BREAK
case 87:
/* rule 87 can match eol */
YY_RULE_SETUP
#line 156 "PRISM.l"
{ line_number++; }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 158 "PRISM.l"
ECHO;
	YY_BREAK
#line 1415 "PRISM.yy.cpp"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(line_directive):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed PRISMin at a new source and called
			 * PRISMlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = PRISMin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( PRISMwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * PRISMtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of PRISMlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					PRISMrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			PRISMrestart(PRISMin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) PRISMrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 253 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 253 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 252);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up PRISMtext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					PRISMrestart(PRISMin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( PRISMwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve PRISMtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void PRISMrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        PRISMensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            PRISM_create_buffer(PRISMin,YY_BUF_SIZE );
	}

	PRISM_init_buffer(YY_CURRENT_BUFFER,input_file );
	PRISM_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void PRISM_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		PRISMpop_buffer_state();
	 *		PRISMpush_buffer_state(new_buffer);
     */
	PRISMensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	PRISM_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (PRISMwrap()) processing, but the only time this flag
	 * is looked at is after PRISMwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void PRISM_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	PRISMin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE PRISM_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) PRISMalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in PRISM_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) PRISMalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in PRISM_create_buffer()" );

	b->yy_is_our_buffer = 1;

	PRISM_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with PRISM_create_buffer()
 * 
 */
    void PRISM_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		PRISMfree((void *) b->yy_ch_buf  );

	PRISMfree((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a PRISMrestart() or at EOF.
 */
    static void PRISM_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	PRISM_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then PRISM_init_buffer was _probably_
     * called from PRISMrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void PRISM_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		PRISM_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void PRISMpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	PRISMensure_buffer_stack();

	/* This block is copied from PRISM_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from PRISM_switch_to_buffer. */
	PRISM_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void PRISMpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	PRISM_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		PRISM_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void PRISMensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)PRISMalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in PRISMensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)PRISMrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in PRISMensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE PRISM_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) PRISMalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in PRISM_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	PRISM_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to PRISMlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       PRISM_scan_bytes() instead.
 */
YY_BUFFER_STATE PRISM_scan_string (yyconst char * yystr )
{
    
	return PRISM_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to PRISMlex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE PRISM_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) PRISMalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in PRISM_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = PRISM_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in PRISM_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up PRISMtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		PRISMtext[PRISMleng] = (yy_hold_char); \
		(yy_c_buf_p) = PRISMtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		PRISMleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int PRISMget_lineno  (void)
{
        
    return PRISMlineno;
}

/** Get the input stream.
 * 
 */
FILE *PRISMget_in  (void)
{
        return PRISMin;
}

/** Get the output stream.
 * 
 */
FILE *PRISMget_out  (void)
{
        return PRISMout;
}

/** Get the length of the current token.
 * 
 */
int PRISMget_leng  (void)
{
        return PRISMleng;
}

/** Get the current token.
 * 
 */

char *PRISMget_text  (void)
{
        return PRISMtext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void PRISMset_lineno (int  line_number )
{
    
    PRISMlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see PRISM_switch_to_buffer
 */
void PRISMset_in (FILE *  in_str )
{
        PRISMin = in_str ;
}

void PRISMset_out (FILE *  out_str )
{
        PRISMout = out_str ;
}

int PRISMget_debug  (void)
{
        return PRISM_flex_debug;
}

void PRISMset_debug (int  bdebug )
{
        PRISM_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from PRISMlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    PRISMin = stdin;
    PRISMout = stdout;
#else
    PRISMin = (FILE *) 0;
    PRISMout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * PRISMlex_init()
     */
    return 0;
}

/* PRISMlex_destroy is for both reentrant and non-reentrant scanners. */
int PRISMlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		PRISM_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		PRISMpop_buffer_state();
	}

	/* Destroy the stack itself. */
	PRISMfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * PRISMlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *PRISMalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *PRISMrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void PRISMfree (void * ptr )
{
	free( (char *) ptr );	/* see PRISMrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 158 "PRISM.l"



int PRISMwrap() {
  return 1;
}

namespace prismparser {

void comment() {
    char c, c1;
	do {
		while ((c = yyinput()) != '*' && c != 0)
                  ;
		if (c=='\n') ++line_number;
	}
    while ((c1 = yyinput()) != '/' && c != 0);
}


int column = 0;

inline void emit(int current_token) {
        token = current_token;
}

int foo() { return yyunput(42,0),2; }
}

